package com.plutext.samples.ole;
/*
 *  Copyright 2016, Plutext Pty Ltd.
 *   
 *  This sample file is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */




import java.io.File;

import org.apache.commons.io.FileUtils;
import org.docx4j.openpackaging.packages.WordprocessingMLPackage;
import org.docx4j.openpackaging.parts.WordprocessingML.MainDocumentPart;
import org.docx4j.wml.P;
import org.docx4j.wml.R;

import com.plutext.ole.EmbeddingType;
import com.plutext.ole.OleHelperDocx;

/**
 * Example of how to link or embed OneNote ".onepkg" Notebook content
 * as an OleObjectBinaryPart inside a docx  
 * 
 * @author Jason Harrop
 */
public class Docx_ole_OneNotePkg {

	static org.docx4j.wml.ObjectFactory wmlObjectFactory = org.docx4j.jaxb.Context.getWmlObjectFactory();
	
	public static void main(String[] args) throws Exception {
		
		
		////////////////////////////////////////////////////////
		// For this sample, create a docx package using docx4j

		WordprocessingMLPackage wordMLPackage = WordprocessingMLPackage.createPackage();
		MainDocumentPart mdp = wordMLPackage.getMainDocumentPart();
		
		////////////////////////////////////////////////////////
		// OLE config

		EmbeddingType embeddingType = EmbeddingType.ONE_PKG; 

		// Link or embed?
		boolean OLE_LINK_ONLY = false;
		
		// Embed
		byte[] contentBytes = FileUtils.readFileToByteArray(
        		new File(System.getProperty("user.dir")+ "/sample.onepkg"));
		
        // or link 
        String targetURL = "file:///F:/sample.onepkg";    // the actual location
		
		// the image on the document surface
		byte[] imageBytes = null; //IconGenerator.createIcon(embeddingType, caption);
				// if imageBytes was null, IconGenerator would be used like that anyway
		
		String caption = "the caption"; // can be anything, but may be used if displaying content rather than icon 		
		
		// position in docx content list
		int index = -1; // place at end
				
		
		
		////////////////////////////////////////////////////////
		// Perform OLE

		P p = new P();
		if (index < 0) {
			mdp.getContents().getContent().add(p);
		} else {
			mdp.getContents().getContent().add(index, p);			
		}
		
		OleHelperDocx OleHelperDocx = new OleHelperDocx(wordMLPackage);
		if (OLE_LINK_ONLY) { 
			
			R r = OleHelperDocx.linkOffice(embeddingType, caption, targetURL, imageBytes);
			p.getContent().add(r);

		    // Save the resulting docx
			wordMLPackage.save(new File(System.getProperty("user.dir")
					+ "/OUT_OneNotePkg_linked.docx"));
			
		} else {
			
			R r = OleHelperDocx.embedOffice(embeddingType, caption,				 
					contentBytes, imageBytes);
			p.getContent().add(r);

		    // Save the resulting docx
			wordMLPackage.save(new File(System.getProperty("user.dir")
					+ "/OUT_OneNotePkg_embedded.docx"));
			
		}
	}
		
	


}
